<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>سىستېما نازارەتچىسى</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>سىستېما نازارەتچىسى سىستېمىڭىزدا ئىجرا بولۇۋاتقان سىستېمىنىڭ يۈكىنى نازارەت قىلىش ، كۆرۈش ۋە كونترول قىلىش جەريانى ۋە مۇلازىمەتلىرىنى نازارەت قىلىدىغان قورال.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>تەپسىلاتىنى يوشۇرۇش</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>ئومۇمىي پايدىلىنىش نىسبىتى</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>شەخسىي پايدىلىنىش نىسبىتى</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>ئوقۇش</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>يېزىش</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 سېكونت</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 كۈن %2 سائەت %3 مىنۇت</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>پايدىلىنىشچانلىقى</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>ھازىرقى چاستوتا</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>چاستوتا</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>ياسىغۇچى</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>ئوقۇر</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>لوگىكىلىق بىر تەرەپ قىلغۇچ</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>مەۋھۇملاشتۇرۇش</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1 غەملەك (بۇيرۇق)</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1 غەملەك (سانلىق مەلۇمات)</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2 غەملەك</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3 غەملەك</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>يۈك تەڭپۇڭلۇقى</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>ھۆججەت چۈشەندۈرۈلۈش خەت سانى</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>جەريانلار</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>لىنىيە سانى</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>ئاپپارات نامى</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>تىپى</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>نەشرى</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>ئىشلىگەن ۋاقىت</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 سېكونت</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>ئىزدەش نەتىجىسى يوق</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>تەپسىلىي ئۇچۇر</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>تەپسىلىي ئۇچۇر</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>ئاكتىپ</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>قايتا يۈكلەش</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>ئاكتىپسىز</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>مەغلۇپ بولدى</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>ئاكتىپلاۋاتىدۇ</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>ئاكتىپلاشتىن قالدۇرۇش</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>تېپىلمىدى</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>ناچار-تەڭشەك</translation>
    </message>
    <message>
        <source>error</source>
        <translation>خاتالىق</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>بىرلەشتۈرۈلدى</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>نىقابلانغان</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>يۈكلەندى</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ئاپتوماتىك</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>قولدا</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>قوزغىتىلدى</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>چەكلەنگەن</translation>
    </message>
    <message>
        <source>static</source>
        <translation>سىتاتىك</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>ئۆتكۈنچى</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>ۋاسىتىلىك</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>قوزغىتىلغان</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>نىقابلانغان</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>ھاسىل قىلىنغان</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>ئۆلدى</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>ئالدىن قوزغىتىش</translation>
    </message>
    <message>
        <source>start</source>
        <translation>باشلاش</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>باشلاش-تۇرقى</translation>
    </message>
    <message>
        <source>running</source>
        <translation>ئىجرا بولۇۋاتىدۇ</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>چىقىپ كەتتى</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>قايتا يۈكلەش</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>توختا</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>مەغلۇپ بولدى</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>auto-restart</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>ئىشلەتكىنى</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>ئىشلەتكىلى بولىدىغىنى</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>ئىچكى ساقلىغۇچ ھەمبەھرىلىنىش</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>يۇقىرى سۈرئەتلىك غەملەك</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>سانلىق مەلۇمات غەملىكى</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>غەملەك ئالماشتۇرۇش رايونى</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>ئاكتىپ</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>پاسسىپ غەملەك ھۆججىتى</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>مەينەت بەت</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>ئەكس ئەتتۈرۈش چوڭلۇقى</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>بوشلۇق ئالماشتۇرۇش سىغىمى</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>ئالماشتۇرۇشقا بولىدىغان بوشلۇق</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>ئىچكى يادرو سانلىق مەلۇمات قۇرۇلمىسى ساقلىغۇچى</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>تىپى</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>ئوقۇش سۈرئىتى</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>يېزىش سۈرئىتى</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>سىغىمى</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>بۇ سېكتورنىڭ قېتىم سانى</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>ھەر سېكونتتىكى مەشغۇلات سانى</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>بۇ سېكتورنى ھەر سېكونتتا ئوقۇش سانى</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>ھەر سېكونتتىكى قوشۇپ مەشغۇلات قىلىش سانى</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>بۇ سېكتورغا يېزىش قېتىم سانى</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>يېزىپ تاماملانغان سانى</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>قوشۇپ يېزىش تاماملانغان سانى</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>ھەر سېكونتتىكى يېزىش سۈرئىتى</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>بۇ سېكتورغا ھەر سېكونتتا يېزىش سانى</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>ھەر سېكونتتىكى قوشۇپ يېزىش سانى</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>ماقۇل</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>سىستېما</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>تېزلەتمە كۆرسەت</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>بۇ جەرياننى ئاخىرلاشتۇرۇش سانلىق مەلۇماتلارنىڭ يوقىلىشىنى كەلتۈرۈپ چىقىرىشى مۇمكىن.
داۋاملاشتۇرۇشنى خالامسىز؟</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>جەرياننى ئاخىرلاشتۇرۇش</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>بۇ جەرياننى ئاخىرلاشتۇرىدىغان كۈچ سانلىق مەلۇماتلارنىڭ يوقىلىشىنى كەلتۈرۈپ چىقىرىشى مۇمكىن.
داۋاملاشتۇرۇشنى خالامسىز؟</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>بۇ پروگراممىنى ئاخىرلاشتۇرىدىغان كۈچ سانلىق مەلۇماتلارنىڭ يوقىلىشىنى كەلتۈرۈپ چىقىرىشى مۇمكىن.
داۋاملاشتۇرۇشنى خالامسىز؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>مەجبۇرى ئاخرلاشتۇرۇش</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>ئاخىرلاشتۇرۇش</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>تەڭشەك</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>سىغىمى</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>IP ئادرېسى:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>تارماق تور يوشۇرۇن نومۇرى:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>رادىيو:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>يوشۇرۇن نومۇر ئۇزۇنلۇقى:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>دائىرە</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>ئۇلىنىش تىپى</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>مۇلازىمىتېرنىڭ باشقا نامى</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>سىگنال سۈپىتى</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>سىگنال كۈچى</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>تۆۋەن شاۋقۇن</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>سۈرئەت نىسبىتى</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>قوبۇللىغان بولاق سانى</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>جەمئىي قوبۇللىغىنى</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>قوبۇللاش(خاتا بولاق)</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>قوبۇللاش(تاشلىۋېتىلگەن بولاق)</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>قوبۇللاش FIFO</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>گۇرۇپپا كاندۇك خاتالىقى</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>يوللانغان بولاق سانى</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>جەمئىي ئەۋەتىلگىنى</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>يوللاش (خاتا بولاق)</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>يوللاشFIFO</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>توشۇش زىيىنى</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>يوللاش (تاشلىۋېتىلگەن بولاق)</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>بۇيرۇق قۇرى</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>باشلىنىش ۋاقتى</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>ئىسمى</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>ئاخىرلاشتۇرماقچى بولغان پروگراممىنى چېكىڭ</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>ساقلىغۇ</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>قوبۇللاش</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>دىسكا ئوقۇش</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>دىسكا يېزىش</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>ساقلىغۇ</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>ئالماشتۇرۇش</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>قوزغىتىلمىدى</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>چۈشۈرۈش</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>يۈكلەش</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>تور</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>ئومۇمىي قوبۇل قىلىنغان</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>ئومۇمىي ئەۋەتىلگەن</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>يوللاش</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>دىسكا</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>بەك ئېگىز</translation>
    </message>
    <message>
        <source>High</source>
        <translation>ئېگىز</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>نورمال</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>تۆۋەن</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>بەك تۆۋەن</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>بەلگىلەش</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>ئىناۋەتسىز</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID:%1 ، خاتالىق: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>جەرياننىڭ تەرتىپىنى ئۆزگەرتەلمىدى</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>قوللىنىشچان پروگراممىلار</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>مېنىڭ جەريانلىرىم</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>بارلىق جەريانلار</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>جەرياننى توختىتالمىدى</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>جەرياننى ئەسلىگە كەلتۈرەلمىدى</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>جەرياننى ئۆلتۈرەلمىدى</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>نامەلۇم خاتالىق</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>بىر تەرەپ قىلىش سىگنالى ئەۋەتىش مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>جەرياننى ئاخىرلاشتۇرمىدى</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 قوللىنىشچان پروگرامما ۋە%2 جەريان ئىجرا بولۇۋاتىدۇ)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>ھېچقانداق جاۋاب يوق</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>توختىتىش</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>تەخسە</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>بۇيرۇق ئورنىنى كۆرۈش</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>خاسلىقى</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>جەرياننى ئاخىرلاشتۇرۇش</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>جەرياننى ئەسلىگە كەلتۈرۈش</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>جەرياننى ئۆلتۈرۈش</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>تەرتىپنى ئۆزگەرتىش</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>جەرياننى توختىتىش</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>ئالدىنلىق دەرىجىسىنى بەلگىلەش</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>ئۆزگەرتىش</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>ئىسمى</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>بىر تەرەپ قىلغۇچ</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>ساقلىغۇ</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>دىسكا يېزىش</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>دىسكا ئوقۇش</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>چۈشۈرۈش</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>يۈكلەش</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>جەريان نومۇرى</translation>
    </message>
    <message>
        <source>User</source>
        <translation>ئىشلەتكۈچى</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>ياخشى</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>ئىمتىيازى</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>ھەمبەھرىلەنگەن ئىچكى ساقلىغۇچ</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>مەۋھۇم ئىچكى ساقلىغۇچ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>قوللىمايدۇ</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەڭشەك</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>سىستېما مۇداپىئەسى</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>سانلىق قىممەت تۆۋەندىكى چەك قىممەتتىن يۇقىرى بولغاندا ئاپتوماتىك سىگنال بەرسۇن</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>ئۇقتۇرۇش</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>CPU نىڭ ئىشلىتىلىشى  (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>ئىچكى ساقلىغۇچنىڭ ئىشلىتىلىشى  (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>سىگنال بېرىش ئارىلىقى (مىنۇت)</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>مۇلازىمەت باشلاش تىپىنى بەلگىلىمىدى</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>خاتالىق: تارماق جەريان چۈشۈپ كەتكەنلىكتىن مۇلازىمەت باشلاش تۈرىنى بەلگىلىمىدى.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>مۇلازىمەت ئۈلگە ئىسمى</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ماقۇل</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>يېڭىلاش</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>باشلاش</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>توختاڭ</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>قايتا قوزغىتىڭ</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ئاپتوماتىك</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>قولدا</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>باشلاش تىپى</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>ئىسمى</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>چۈشۈرۈش</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>ئاكتىپ</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>قوشۇمچە</translation>
    </message>
    <message>
        <source>State</source>
        <translation>ھالەت</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>چۈشەندۈرۈش</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>جەريان نومۇرى</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>باشلاش تىپى</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>تەڭشەك</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(چەك قىممەتنى ئۆزگەرتىشكە بولىدۇ)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>قىممەت دائىرىسى: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>قوللىنىشچان پروگراممىنى كۈچلەندۈرۈش</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>كېڭەيتىش</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>ئىخچام</translation>
    </message>
    <message>
        <source>View</source>
        <translation>كۆرۈش</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>ئىزدەش</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>جەريانلار</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>مۇلازىمەتلەر</translation>
    </message>
</context>
</TS>
